@@ -1,18 +1,14 @@
 from pydantic import BaseModel
-from abc import ABC
-from abc import abstractmethod as _abstractmethod
+from abc import abstractmethod as _abstractmethod, ABC
 from typing import Any
 
 
 class Relation:
-    def __init__(self, tablename: str, where: dict[str, Any], ext_schema_t: 'SchemaType', fieldname: str,
-                 rel_schema_t: 'SchemaType' = dict[str, Any], columns: list[str] = None):
-        self.tablename: str = tablename
+    def __init__(self, ext_schema_t: type['Schema'], propname: str, rel_schema_t: type['Schema'], where: dict[str, Any]):
         self.where: dict[str, Any] = where
-        self.ext_schema_t: 'SchemaType' = ext_schema_t
-        self.fieldname: str = fieldname
-        self.rel_schema_t: 'SchemaType' = rel_schema_t
-        self.columns: list[str] = columns if columns else ['*']
+        self.ext_schema_t: type['Schema'] = ext_schema_t
+        self.fieldname: str = propname
+        self.rel_schema_t: type['Schema'] = rel_schema_t
 
 
 class Schema(BaseModel, ABC):
