@@ -2,7 +2,6 @@ from apidevtools import inf
 
 from .. import schemas
 from ..const import db
-from .field import get_fields, delete_field
 
 
 async def create_item(user_id: int, item: schemas.ItemCreate) -> schemas.Item:
@@ -19,7 +18,7 @@ async def get_item(item_id: int, schema: type = schemas.Item) -> schemas.Item |
 
 async def get_items(user_id: int, limit: int = inf, offset: int = 0, schema: type = schemas.Item) -> list[schemas.Item]:
     query, args = f'SELECT * FROM "item" WHERE "user_id" = $1 LIMIT $2 OFFSET $3;', (user_id, limit, offset)
-    db_items = (await db.select(query, args, schema)).all()
+    db_items = (await db.select(query, args, schema)).order_by(['title']).all()
     return db_items
 
 
@@ -28,9 +27,6 @@ async def update_item(item_id: int, item: schemas.ItemCreate) -> schemas.Item:
     return db_item
 
 
-async def delete_item(item_id: int) -> None:
-    db_fields = await get_fields(item_id=item_id)
-    for db_field in db_fields:
-        await delete_field(field_id=db_field.id)
-    query, args = f'DELETE FROM "item" WHERE "id" = $1;', (item_id, )
-    await db.execute(query, args)
+async def delete_item(item_id: int) -> schemas.Item:
+    db_item = await db.delete(dict(id=item_id), schemas.Item, 'item')
+    return db_item
