@@ -1,4 +1,4 @@
-from apidevtools import Schema
+from apidevtools import Schema, Relation
 
 from .item import Item
 
@@ -18,14 +18,12 @@ class UserCreate(UserBase):
     password: str
 
 
-class UserUpdate(UserBase):
-    ...
-
-
 class User(UserBase):
     id: int
 
     items: list[Item] = []
 
     def relations(self) -> list[Relation]:
-        return [Relation('item', dict(user_id=self.id), User, 'items', ['*'], Item)]
+        return [
+            Relation('item', dict(user_id=self.id), User, 'items', Item, ['*']),
+        ]
